package SPVM::File::Find::Handler;



1;

=head1 Name

SPVM::File::Find::Handler - Handler for File::Find

=head1 Description

The File::Find::Handler class of L<SPVM> has interface methods for the handler of L<File::Find|SPVM::File::Find>.

=head1 Usage

  use File::Find::Handler;

=head1 Interface Methods

  required method : void ($dir : string, $file_base_name : string);

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

